psychopy_ext.exp.set_paths — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.set_paths

`psychopy_ext.exp.` `set_paths`(exp_root='.', computer=<class psychopy_ext.exp.default_computer at 0x120781F0>, fmri_rel='')

  Set paths to data storage.

  Args: | exp_root (str) Path to where the main file that starts the program is.
  Kwargs: | computer (Namespace, default: `default_computer`) A class with a computer parameters defined, such as the default path for storing data, size of screen etc. See `default_computer` for an example. fmri_rel (str, default: ‘’) A path to where fMRI data and related analyzes should be stored. This is useful because fMRI data takes a lot of space so you may want to keep it on an external hard drive rather than on Dropbox where your scripts might live, for example.
  Returns: | paths (dict): A dictionary of paths.